@@ -1,4 +1,4 @@
-from sangreal_wind.sangreal_calendar import Monthly
+from sangreal_wind.sangreal_calendar import Monthly, step_trade_dt
 from sangreal_wind.utils.datetime_handle import dt_handle
 from sangreal_wind.utils.engines import WIND_DB
 
@@ -11,6 +11,7 @@ def get_daily_ret(
         trade_dt=None,
         begin_dt='20030101',
         end_dt='20990101',
+        universe='A',
 ):
     """[get daily_ret of stocks,]
 
@@ -23,10 +24,15 @@ def get_daily_ret(
     Returns:
         ret {pd.DataFrame} -- [sid: trade_dt]
     """
+    if universe not in ('A', 'HK'):
+        raise ValueError('universe only support A or HK!')
     begin_dt, end_dt = dt_handle(begin_dt), dt_handle(end_dt)
-    table = getattr(WIND_DB, 'AShareEODPrices'.upper())
+    if universe == 'A':
+        table = getattr(WIND_DB, 'AShareEODPrices'.upper())
+    else:
+        table = getattr(WIND_DB, 'HKSHAREEODPRICES'.upper())
     query = WIND_DB.query(table.S_INFO_WINDCODE, table.TRADE_DT,
-                          table.S_DQ_PCTCHANGE)
+                          table.S_DQ_ADJCLOSE)
     if sid is not None:
         if isinstance(sid, str):
             query = query.filter(table.S_INFO_WINDCODE == sid)
@@ -36,14 +42,13 @@ def get_daily_ret(
     if trade_dt is not None:
         begin_dt = end_dt = dt_handle(trade_dt)
     df = query.filter(
-        table.TRADE_DT >= begin_dt, table.TRADE_DT <= end_dt).order_by(
+        table.TRADE_DT >= step_trade_dt(begin_dt, -1), table.TRADE_DT <= end_dt).order_by(
             table.TRADE_DT).to_df()
     df.columns = ['sid', 'trade_dt', 'pct_change']
     df = df.pivot(values='pct_change', index='trade_dt', columns='sid')
-    df = df / 100.0
 
     # # 防止出现0的情况，强制缺失na
-    # df = df.pct_change(fill_method=None)
+    df = df.pct_change(fill_method=None)
     df.dropna(how='all', inplace=True)
     return df.T
 
