@@ -153,6 +153,7 @@ class DynamicUniverse:
 
     indx = attr.ib()
     index = attr.ib(init=False)
+    members = attr.ib(init=None)
 
     @indx.validator
     def check(self, attribute, value):
@@ -166,28 +167,22 @@ class DynamicUniverse:
         except KeyError:
             self.index = self.indx
 
-    def preview(self, trade_dt, weight=False):
-        if not weight:
-            if self.indx == 'MSCI':
-                df = get_all_msci()
-            elif self.indx == 'A':
-                df = get_all_stk()
-            elif self.indx == 'CBOND':
-                df = get_all_bond()
-            elif self.index != '':
-                df = get_all_normal_index(self.index)
+    def preview(self, trade_dt):
+        if isinstance(self.members, pd.DataFrame):
+            df = self.members.copy()
+        elif self.indx == 'MSCI':
+            df = get_all_msci()
+        elif self.indx == 'A':
+            df = get_all_stk()
+        elif self.indx == 'CBOND':
+            df = get_all_bond()
+        elif self.index != '':
+            df = get_all_normal_index(self.index)
 
-            trade_dt = dt_handle(trade_dt)
-            df = df.loc[(df['entry_dt'] <= trade_dt) & (
-                (df['out_dt'] >= trade_dt) | (df['out_dt'].isnull()))]
-            return set(df.sid)
-        else:
-            df = get_index_weight(index=self.index, trade_dt=trade_dt)
-            if not df.empty:
-                df.set_index('sid', inplace=True)
-                return df
-            else:
-                raise ValueError(f'{self.index}无权重数据！')
+        trade_dt = dt_handle(trade_dt)
+        df = df.loc[(df['entry_dt'] <= trade_dt) & (
+            (df['out_dt'] >= trade_dt) | (df['out_dt'].isnull()))]
+        return set(df.sid)
 
 
 if __name__ == '__main__':
