@@ -12,3 +12,5 @@ def tmp_data():
 
 
 CALENDAR.inject(tmp_data())
+DELISTDATE = get_delistdate_all()
+DELISTDATE_TF = get_delistdate_tf_all()
